#---------------------------------------------------------------------------
#
#   SuPy GUI - Container - Generic
#
#---------------------------------------------------------------------------

from properties import overridable_property
from widget import Widget

class GContainer(Widget):

	contents = overridable_property('contents', "Contained widgets")
	
	def __init__(self, **kwds):
		self._contents = []
		Widget.__init__(self, **kwds)

	def get_contents(self):
		return self._contents

	def destroy(self):
		self.container = None
		for widget in self.contents:
			widget.destroy()
		Widget.destroy(self)

	def add(self, item):
		"""Add a widget or sequence of widgets to this container."""
		if isinstance(item, Widget):
			item.container = self
		else:
			for subitem in item:
				self.add(subitem)
	
	def remove(self, item):
		"""Remove a widget or sequence of widgets from this container."""
		if isinstance(item, Widget):
			if item in self._contents:
				item.container = None
		else:
			for subitem in item:
				self.remove(subitem)
