###############################################################
#
#   SuPy - Ruby initialization and utility code
#
###############################################################

require 'python'

def Py.refresh()
	Py::Supy.reload_all()
	Py._ruby_refresh()
end

#
#   Add the python and python/lib directories to Python's module search path.
#
plugins = Sketchup.find_support_file("plugins")
python = plugins + "/python"
syspath = Py::Sys.path
syspath.insert(0, plugins + "/supy/tests")
syspath.insert(0, plugins + "/supy")
syspath.insert(0, python + "/lib")
syspath.insert(0, python)

#
#   Load Python code for initializing supy.
#
supy = Py::Sys.modules.get("supy")
if supy == nil
	require 'python/supy'
	supy = Py::Supy
else
	Py.reload(supy)
end

#
#   Direct Python standard output to the Ruby console.
#
supy.set_stdout($stdout)

#
#   Inject the Sketchup API classes into the Python builtin namespace.
#
supy.init_module(Sketchup)
supy.init_module(Geom)
supy.init_module(UI)
supy.init_name('Array', proc {|x| Array(x)})
supy.init_name('X_AXIS', X_AXIS)
supy.init_name('Y_AXIS', Y_AXIS)
supy.init_name('Z_AXIS', Z_AXIS)
supy.init_name('cm', 1.cm)
supy.init_name('degrees', 1.degrees)
supy.init_name('feet', 1.feet)
supy.init_name('inch', 1.inch)
supy.init_name('km', 1.km)
supy.init_name('m', 1.m)
supy.init_name('mile', 1.mile)
supy.init_name('mm', 1.mm)
supy.init_name('radians', 1.radians)
supy.init_name('yard', 1.yard)
supy.init_name('CONSTRAIN_MODIFIER_KEY', CONSTRAIN_MODIFIER_KEY)
supy.init_name('CONSTRAIN_MODIFIER_MASK', CONSTRAIN_MODIFIER_MASK)
supy.init_name('COPY_MODIFIER_KEY', COPY_MODIFIER_KEY)
supy.init_name('COPY_MODIFIER_MASK', COPY_MODIFIER_MASK)
supy.init_name('ALT_MODIFIER_KEY', ALT_MODIFIER_KEY)
supy.init_name('ALT_MODIFIER_MASK', ALT_MODIFIER_MASK)
supy.init_name('SB_PROMPT', SB_PROMPT)
supy.init_name('SB_VCB_LABEL', SB_VCB_LABEL)
supy.init_name('SB_VCB_VALUE', SB_VCB_VALUE)

#
#   Ruby modules to be mixed in with Python base class wrappers.
#

load 'supy/tool.rb'
load 'supy/observer.rb'

#
#   Ruby functions used by supy support code.
#

supy.init_private('to_l', proc {|x| x.to_l})

#
#   Load scripts from the python directory under plugins.
#
Py.refresh()
